/*
 * @Author: yeminglong
 * @Date: 2023-12-15 09:44:31
 * @LastEditTime: 2023-12-15 11:16:18
 * @LastEditors: yeminglong
 * @Description:
 */
const TerserPlugin = require('terser-webpack-plugin')
const CompressionPlugin = require('compression-webpack-plugin')
const { resolve } = require('path')
const productionGzipExtensions = /\.(js|css)(\?.*)?$/i
const CopyPlugin = require('copy-webpack-plugin')
const path = require('path')
module.exports = {
  productionSourceMap: process.env.NODE_ENV === 'development',
  publicPath: process.env.NODE_ENV === 'production' ? './' : '/',
  outputDir: './dist',
  configureWebpack: {
    optimization: {
      minimize: process.env.NODE_ENV === 'production',
      minimizer: [
        new TerserPlugin({
          test: /\.js(\?.*)?$/i, // 匹配参与压缩的文件
          parallel: true, // 使用多进程并发运行
          terserOptions: {
            // Terser 压缩配置
            output: { comments: false },
            compress: {
              drop_console: true,
              drop_debugger: false,
              pure_funcs: ['console.log']
            }
          },
          extractComments: false // 将注释剥离到单独的文件中
        })
      ]
    },
    plugins: [
      new CopyPlugin([
        {
          // from: path.resolve(__dirname, 'src/assets/decoder.js'),
          // to: path.resolve(__dirname, 'public')
          from: `${__dirname}/src/assets/decoder.js`,
          to: `${__dirname}/public`
        },
        {
          // from: path.resolve(__dirname, 'src/assets/decoder.wasm'),
          // to: path.resolve(__dirname, 'public')
          from: `${__dirname}/src/assets/decoder.wasm`,
          to: `${__dirname}/public`
        }
      ])
    ]
  },
  chainWebpack: config => {
    // 添加别名
    config.resolve.alias.set('@', resolve('src'))
    if (process.env.NODE_ENV === 'production') {
      // 压缩
      config.plugin('compressionPlugin').use(
        new CompressionPlugin({
          filename: '[path].gz[query]',
          algorithm: 'gzip',
          test: productionGzipExtensions,
          threshold: 10240,
          minRatio: 0.8
          // deleteOriginalAssets: true
        })
      )
    }
    config.module
      .rule('swf')
      .test(/\.swf$/)
      .use('url-loader')
      .loader('url-loader')
      .options({
        limit: 10000
      })
  }
}
